pub struct ResourceTexture {
pub hat: [TextureElement; 132],
pub eye: [TextureElement; 62],
pub eyebrow: [TextureElement; 24],
pub beard: [TextureElement; 2],
pub wrinkle: [TextureElement; 12],
pub makeup: [TextureElement; 12],
pub glass: [TextureElement; 20],
pub mole: [TextureElement; 2],
pub mouth: [TextureElement; 37],
pub mustache: [TextureElement; 6],
pub noseline: [TextureElement; 18],
/* private fields */
}Expand description
Header of the Texture resource file. Contains texture data for CharModels.
Fields
hat: [TextureElement; 132]eye: [TextureElement; 62]eyebrow: [TextureElement; 24]beard: [TextureElement; 2]wrinkle: [TextureElement; 12]makeup: [TextureElement; 12]glass: [TextureElement; 20]mole: [TextureElement; 2]mouth: [TextureElement; 37]mustache: [TextureElement; 6]noseline: [TextureElement; 18]Trait Implementations
Sourceimpl BinRead for ResourceTexture
impl BinRead for ResourceTexture
Sourcefn read_options<R: Read + Seek>(
__binrw_generated_var_reader: &mut R,
__binrw_generated_var_endian: Endian,
__binrw_generated_var_arguments: Self::Args<'_>,
) -> BinResult<Self>
fn read_options<R: Read + Seek>( __binrw_generated_var_reader: &mut R, __binrw_generated_var_endian: Endian, __binrw_generated_var_arguments: Self::Args<'_>, ) -> BinResult<Self>
Sourcefn read<R>(reader: &mut R) -> Result<Self, Error>
fn read<R>(reader: &mut R) -> Result<Self, Error>
Read
Self from the reader using default arguments. Read moreSourcefn read_be<R>(reader: &mut R) -> Result<Self, Error>
fn read_be<R>(reader: &mut R) -> Result<Self, Error>
Read
Self from the reader using default arguments and assuming
big-endian byte order. Read moreSourcefn read_le<R>(reader: &mut R) -> Result<Self, Error>
fn read_le<R>(reader: &mut R) -> Result<Self, Error>
Read
Self from the reader using default arguments and assuming
little-endian byte order. Read moreSourcefn read_ne<R>(reader: &mut R) -> Result<Self, Error>
fn read_ne<R>(reader: &mut R) -> Result<Self, Error>
Read
T from the reader assuming native-endian byte order. Read moreSourcefn read_args<R>(reader: &mut R, args: Self::Args<'_>) -> Result<Self, Error>
fn read_args<R>(reader: &mut R, args: Self::Args<'_>) -> Result<Self, Error>
Read
Self from the reader using the given arguments. Read moreSourcefn read_be_args<R>(reader: &mut R, args: Self::Args<'_>) -> Result<Self, Error>
fn read_be_args<R>(reader: &mut R, args: Self::Args<'_>) -> Result<Self, Error>
Read
Self from the reader, assuming big-endian byte order, using the
given arguments. Read moreSourceimpl Clone for ResourceTexture
impl Clone for ResourceTexture
Sourcefn clone(&self) -> ResourceTexture
fn clone(&self) -> ResourceTexture
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for ResourceTexture
Sourceimpl ReadEndian for ResourceTexture
impl ReadEndian for ResourceTexture
Sourceconst ENDIAN: EndianKind
const ENDIAN: EndianKind
The endianness of the type.